@@ -5,12 +5,11 @@ use Carp;
 use Text::CSV;
 use Scalar::Util qw( reftype );
 use Cwd;
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 use Parse::Taxonomy::Auxiliary qw(
     path_check_fields
     components_check_fields
 );
-#use Data::Dump;
 
 =head1 NAME
 
@@ -78,7 +77,7 @@ with the same parent ID.  Defaults to C<name>.
 
 =item * Text::CSV options
 
-Any other options which could normally be passed to C<Text::CSV->new()> will
+Any other options which could normally be passed to C<Text::CSV-E<gt>new()> will
 be passed through to that module's constructor.  On the recommendation of the
 Text::CSV documentation, C<binary> is always set to a true value.
 
@@ -415,8 +414,6 @@ Read-only.
 
 =back
 
-# Implemented in lib/Parse/Taxonomy.pm
-
 =head2 C<data_records()>
 
 =over 4
@@ -445,8 +442,6 @@ or (b) use C<fields_and_data_records()>.
 
 =back
 
-# Implemented in lib/Parse/Taxonomy.pm
-
 =cut
 
 =head2 C<get_field_position()>
@@ -473,8 +468,6 @@ field.
 
 =cut
 
-# Implemented in lib/Parse/Taxonomy.pm
-
 =head2 Accessors
 
 The following methods provide information about key columns in a
