@@ -6,12 +6,11 @@ use Text::CSV;
 use Scalar::Util qw( reftype );
 use List::Util qw( max );
 use Cwd;
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 use Parse::Taxonomy::Auxiliary qw(
     path_check_fields
     components_check_fields
 );
-#use Data::Dump;
 
 =head1 NAME
 
@@ -87,7 +86,7 @@ Optional; defaults to C<|>.
 
 =item *  Text::CSV options
 
-Any other options which could normally be passed to C<Text::CSV->new()> will
+Any other options which could normally be passed to C<Text::CSV-E<gt>new()> will
 be passed through to that module's constructor.  On the recommendation of the
 Text::CSV documentation, C<binary> is always set to a true value.
 
@@ -157,7 +156,7 @@ incoming taxonomy file.
 =item * In the column designated as the "path" column, the same value is
 observed more than once.
 
-=item * C<id>, C<parent_id> and C<name> are reserved.  One or more columns is
+=item * C<id>, C<parent_id> and C<name> are reserved terms.  One or more columns is
 named with a reserved term.
 
 =item * A non-parent node's parent node cannot be located in the incoming taxonomy file.
@@ -376,8 +375,6 @@ Read-only.
 
 =back
 
-# Implemented in lib/Parse/Taxonomy.pm
-
 =head2 C<path_col_idx()>
 
 =over 4
@@ -504,8 +501,6 @@ or (b) use C<fields_and_data_records()>.
 
 =back
 
-# Implemented in lib/Parse/Taxonomy.pm
-
 =head2 C<fields_and_data_records()>
 
 =over 4
@@ -532,8 +527,6 @@ in that file.
 
 =cut
 
-# Implemented in lib/Parse/Taxonomy.pm
-
 =head2 C<data_records_path_components()>
 
 =over 4
@@ -655,8 +648,6 @@ field.
 
 =cut
 
-# Implemented in lib/Parse/Taxonomy.pm
-
 =head2 C<child_counts()>
 
 =over 4
